"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handler = void 0;

var _fsExtra = _interopRequireDefault(require("fs-extra"));

var _sharp = _interopRequireDefault(require("sharp"));

var _mimeTypes = _interopRequireDefault(require("mime-types"));

var _path = _interopRequireDefault(require("path"));

const UPLOADS_FOLDER = process.env.UPLOADS_FOLDER || ".files";

const handler = async ({
  pathParameters,
  queryStringParameters
}) => {
  const {
    key
  } = pathParameters;

  const type = _mimeTypes.default.lookup(key);

  try {
    const folder = _path.default.resolve(UPLOADS_FOLDER);

    let buffer = await _fsExtra.default.readFile(_path.default.join(folder, "/", key));

    if (queryStringParameters) {
      // If an image was requested, we can apply additional image processing.
      const {
        width,
        height
      } = queryStringParameters;

      if (width || height) {
        const supportedImageTypes = ["image/jpg", "image/jpeg", "image/png"];

        if (supportedImageTypes.includes(type)) {
          buffer = await (0, _sharp.default)(buffer).resize({
            width: parseInt(width),
            height: parseInt(height)
          }).toBuffer();
        }
      }
    }

    return {
      statusCode: 200,
      headers: {
        "Access-Control-Allow-Origin": "*",
        "Content-Type": type
      },
      body: buffer
    };
  } catch (e) {
    return {
      statusCode: 404,
      headers: {
        "Access-Control-Allow-Origin": "*"
      }
    };
  }
};

exports.handler = handler;
//# sourceMappingURL=download.js.map