"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handler = void 0;

var _uniqid = _interopRequireDefault(require("uniqid"));

var _mimeTypes = _interopRequireDefault(require("mime-types"));

var _sanitizeFilename = _interopRequireDefault(require("sanitize-filename"));

const respond = body => {
  return {
    statusCode: 200,
    headers: {
      "Access-Control-Allow-Origin": "*"
    },
    body: JSON.stringify(body, null, 2)
  };
};

const respondWithError = message => {
  return respond({
    code: "FILE_UPLOAD_FAILED",
    data: {
      message
    }
  });
};

const handler = async event => {
  const options = JSON.parse(event.body);
  const {
    name,
    type,
    size
  } = options;

  if (!name) {
    return respondWithError(`File "name" missing.`);
  }

  if (!size) {
    return respondWithError(`File "size" missing.`);
  }

  if (!type) {
    return respondWithError(`File "type" missing.`);
  }

  const contentType = _mimeTypes.default.lookup(name);

  if (!contentType) {
    return respondWithError(`File's content type could not be resolved.`);
  }

  if (contentType !== type) {
    return respondWithError(`Detected and received file types don't match.`);
  }

  let key = (0, _sanitizeFilename.default)(name);

  if (key) {
    key = (0, _uniqid.default)() + "_" + key;
  } // Replace all whitespace.


  key = key.replace(/\s/g, "");
  return respond({
    code: "FILE_UPLOAD_SUCCESS",
    data: {
      file: {
        name: key,
        src: "/files/" + key,
        type: contentType,
        size
      },
      s3: {
        url: "/files/upload",
        fields: {
          "Content-Length": size,
          "Content-Type": contentType,
          key
        }
      }
    }
  });
};

exports.handler = handler;
//# sourceMappingURL=uploadRequest.js.map